SystemOrganization addCategory: #'DuinoBot-Core'!
SystemOrganization addCategory: #'DuinoBot-Core-Firmware'!

ArduinoDirectMode subclass: #DuinoBotDirectMode
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core-Firmware'!

!DuinoBotDirectMode methodsFor: 'as yet unclassified' stamp: 'Richo 4/18/2012 17:00'!
controlFirmwareInstalled
	| time timeout |
	time := Time millisecondClockValue.
	timeout := 5000.
	[100 milliSeconds asDelay wait.
	('*HOLA, SOY DUINOBOT*' match: port readString)
		ifTrue: [
			port nextPutAll: (ByteArray with: 255).
			[port readString = ''] whileFalse.
			^ self]]
		doWhileTrue: [Time millisecondClockValue - time < timeout].
	^ FirmwareNotInstalled signal! !

!DuinoBotDirectMode methodsFor: 'as yet unclassified' stamp: 'Richo 8/31/2011 17:33'!
motorDC: motorIndex speed: pinValue
	| speed |
	speed := (1.275 * pinValue + 127.5) rounded.
	self send: {self asCommand: self class rqMotorDC.
						self asArgument: motorIndex.
						self asArgument: (speed bitAnd: 2r01111111).
						self asArgument: (speed bitAnd: 2r10000000) >> 7} asByteArray! !

Arduino subclass: #DuinoBot
	instanceVariableNames: 'motorPins'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core'!

!DuinoBot class methodsFor: 'as yet unclassified' stamp: 'Richo 5/15/2012 15:10'!
defaultProtocol
	^ DuinoBotDirectMode! !

!DuinoBot methodsFor: 'initialize-release' stamp: 'Richo 3/6/2012 09:57'!
initialize
	super initialize.
	motorPins := Dictionary newFrom: ((0 to: 1)
				collect: [:i | i -> (DuinoBotMotorPin on: self number: i)])! !

!DuinoBot methodsFor: 'motors' stamp: 'Richo 8/31/2011 15:20'!
motorPin: index
	^ motorPins at: index ifAbsent: [self inaccessiblePinError]! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 10/24/2012 15:44'!
motorPins
	^ motorPins values
! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 10/24/2012 15:56'!
pins
	^ super pins, self motorPins! !

!DuinoBot methodsFor: 'initialize-release' stamp: 'Richo 4/18/2012 13:34'!
reconfigurePins
	"Overriden to avoid DuinoBot issue on Linux"
	digitalPins values , analogPins values
		do: [:each | 
			100 milliSeconds asDelay wait.
			each refresh]! !

ArduinoType subclass: #DuinoBotType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core'!

!DuinoBotType class methodsFor: 'accessing types' stamp: 'Richo 11/23/2012 12:34'!
default
	^ self at: #'DuinoBot.v1.x.HID'! !

!DuinoBotType class methodsFor: 'accessing types' stamp: 'Richo 11/23/2012 12:36'!
hidTypes
	^ {self at: #'DuinoBot.v1.x.HID'}! !

!DuinoBotType class methodsFor: 'class initialization' stamp: 'Richo 11/23/2012 13:38'!
initialize
	"
	self initialize.
	"
	types := Dictionary new.

	types
		at: #DuinoBotCDC
		put: (DuinoBotType
			friendlyNames: #('duinobot 1.x' )
			fCpu: 16000000
			mcu: 'atmega32u4'
			uploadRate: 115200
			firmataRate: 57600
			avrdudeProgrammer: 'avr109').

	types
		at: #'DuinoBot.v1.x.HID'
		put: (DuinoBotType
			friendlyNames: #('duinobot 1.x hid' )
			fCpu: 16000000
			mcu: 'atmega32u4'
			uploadRate: 115200
			firmataRate: 57600
			avrdudeProgrammer: 'avr109')! !

!DuinoBotType methodsFor: 'testing' stamp: 'Richo 11/23/2012 12:36'!
isHID
	^ self class hidTypes includes: self! !

AttachableDevice subclass: #RGMotor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core'!

!RGMotor methodsFor: 'as yet unclassified' stamp: 'Richo 9/7/2011 11:15'!
brake
	self controlAttaching; reconfigureIfNecessary.
	pins first value: 0! !

!RGMotor methodsFor: 'as yet unclassified' stamp: 'Richo 9/7/2011 11:15'!
configure
	pins first refresh! !

!RGMotor methodsFor: 'as yet unclassified' stamp: 'Richo 9/7/2011 11:15'!
deleteConfiguration
	pins first value: 0! !

!RGMotor methodsFor: 'accessing' stamp: 'Richo 10/24/2012 17:15'!
motorID
	^ pins first number! !

!RGMotor methodsFor: 'as yet unclassified' stamp: 'Richo 9/7/2011 11:10'!
speed
	self controlAttaching; reconfigureIfNecessary.
	^ pins first value! !

!RGMotor methodsFor: 'as yet unclassified' stamp: 'Richo 9/7/2011 11:11'!
speed: aNumber
	self controlAttaching; reconfigureIfNecessary.
	pins first value: aNumber! !

ArduinoPin subclass: #DuinoBotMotorPin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core'!

!DuinoBotMotorPin methodsFor: 'as yet unclassified' stamp: 'Richo 3/6/2012 09:56'!
refresh
	self protocol motorDC: number speed: value
! !

!DuinoBotMotorPin methodsFor: 'as yet unclassified' stamp: 'Richo 9/1/2011 14:19'!
value
	^ value! !

!DuinoBotMotorPin methodsFor: 'as yet unclassified' stamp: 'Richo 8/31/2011 15:28'!
value: speed
	value := (speed min: 100 max: -100).
	self refresh! !
DuinoBotType initialize!
